==> certmanager-model-v1alpha2-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<A extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent() {
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent(ACMEChallengeSolverHTTP01IngressPodObjectMeta instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodObjectMeta());

    if (instance != null) {
      this.withAnnotations(instance.getAnnotations());
      this.withLabels(instance.getLabels());
      this.withAnnotations(instance.getAnnotations());
      this.withLabels(instance.getLabels());
    }
  }
  private Map<String,String> annotations;
  private Map<String,String> labels;
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabels() {
    return this.labels;
  }
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  public boolean hasLabels() {
    return this.labels != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent that = (ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;

    if (!java.util.Objects.equals(labels, that.labels)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotations,  labels,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha2-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha2/ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha2;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<A extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent<A>> extends BaseFluent<A>{
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent() {
  }
  
  public ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent(ACMEChallengeSolverHTTP01IngressPodObjectMeta instance) {
    this.copyInstance(instance);
  }
  private Map<String,String> annotations;
  private Map<String,String> labels;
  
  protected void copyInstance(ACMEChallengeSolverHTTP01IngressPodObjectMeta instance) {
    instance = (instance != null ? instance : new ACMEChallengeSolverHTTP01IngressPodObjectMeta());
  
    if (instance != null) {
        this.withAnnotations(instance.getAnnotations());
        this.withLabels(instance.getLabels());
        this.withAnnotations(instance.getAnnotations());
        this.withLabels(instance.getLabels());
      }
  }
  
  public A addToAnnotations(String key,String value) {
    if(this.annotations == null && key != null && value != null) { this.annotations = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotations.put(key, value);} return (A)this;
  }
  
  public A addToAnnotations(Map<String,String> map) {
    if(this.annotations == null && map != null) { this.annotations = new LinkedHashMap(); }
    if(map != null) { this.annotations.putAll(map);} return (A)this;
  }
  
  public A removeFromAnnotations(String key) {
    if(this.annotations == null) { return (A) this; }
    if(key != null && this.annotations != null) {this.annotations.remove(key);} return (A)this;
  }
  
  public A removeFromAnnotations(Map<String,String> map) {
    if(this.annotations == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotations != null){this.annotations.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getAnnotations() {
    return this.annotations;
  }
  
  public <K,V>A withAnnotations(Map<String,String> annotations) {
    if (annotations == null) { this.annotations =  null;} else {this.annotations = new LinkedHashMap(annotations);} return (A) this;
  }
  
  public boolean hasAnnotations() {
    return this.annotations != null;
  }
  
  public A addToLabels(String key,String value) {
    if(this.labels == null && key != null && value != null) { this.labels = new LinkedHashMap(); }
    if(key != null && value != null) {this.labels.put(key, value);} return (A)this;
  }
  
  public A addToLabels(Map<String,String> map) {
    if(this.labels == null && map != null) { this.labels = new LinkedHashMap(); }
    if(map != null) { this.labels.putAll(map);} return (A)this;
  }
  
  public A removeFromLabels(String key) {
    if(this.labels == null) { return (A) this; }
    if(key != null && this.labels != null) {this.labels.remove(key);} return (A)this;
  }
  
  public A removeFromLabels(Map<String,String> map) {
    if(this.labels == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labels != null){this.labels.remove(key);}}} return (A)this;
  }
  
  public Map<String,String> getLabels() {
    return this.labels;
  }
  
  public <K,V>A withLabels(Map<String,String> labels) {
    if (labels == null) { this.labels =  null;} else {this.labels = new LinkedHashMap(labels);} return (A) this;
  }
  
  public boolean hasLabels() {
    return this.labels != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent that = (ACMEChallengeSolverHTTP01IngressPodObjectMetaFluent) o;
    if (!java.util.Objects.equals(annotations, that.annotations)) return false;
  
    if (!java.util.Objects.equals(labels, that.labels)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(annotations,  labels,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotations != null && !annotations.isEmpty()) { sb.append("annotations:"); sb.append(annotations + ","); }
    if (labels != null && !labels.isEmpty()) { sb.append("labels:"); sb.append(labels); }
    sb.append("}");
    return sb.toString();
  }
  

}
